\name{Cholesky-class}
\docType{class}
\alias{Cholesky-class}

\title{Cholesky decompositions}
\description{The \code{"Cholesky"} class is the class of Cholesky
  decomposition of a positive-semidefinite, real matrices}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("Cholesky", ...)}
  or by calls of the form \code{chol(pm)} where \code{pm} inherits from
  the \code{"poMatrix"} class or as a side-effect of other functions
  applied to \code{"poMatrix"} objects.
}
\section{Slots}{
  \describe{
    \item{\code{uplo}:}{inherited from the \code{"trMatrix"} class.}
    \item{\code{diag}:}{inherited from the \code{"trMatrix"} class.}
    \item{\code{x}:}{inherited from the \code{"trMatrix"} class.}
    \item{\code{Dim}:}{inherited from the \code{"trMatrix"} class.}
    \item{\code{rcond}:}{inherited from the \code{"trMatrix"} class.}
    \item{\code{factorization}:}{inherited from the \code{"trMatrix"}
      class.  For this class the \code{factorization} slot is always an
      empty list.}
  }
}
\section{Extends}{
Class \code{"trMatrix"}, directly.
Class \code{"geMatrix"}, by class \code{"trMatrix"}.
Class \code{"Matrix"}, by class \code{"trMatrix"}.
}
\section{Methods}{
No methods defined with class "Cholesky" in the signature.
}
\seealso{
  \code{\link{trMatrix-class}}, \code{chol}, \code{poMatrix-class}
}
\examples{
print(pm <- crossprod(Matrix(rnorm(18), nrow = 6, ncol = 3)))
print(ch <- chol(pm))
if (toupper(ch@uplo) == "U") crossprod(ch)
}
\keyword{classes}
\keyword{algebra}

\eof
\name{Hilbert}
\alias{Hilbert}
\title{Generate a Hilbert matrix}
\description{
    Generate the \code{n} by \code{n} symmetric Hilbert matrix.  Because
    these matrices are ill-conditioned for moderate to large \code{n},
    they are often used for testing numerical linear algebra code.
}
\usage{
Hilbert(n)
}
\arguments{
  \item{n}{a positive integer.}
}
\value{
  the \code{n} by \code{n} symmetric Hilbert matrix as a
  \code{"poMatrix"} object.
}
\seealso{\code{\link{poMatrix-class}}}  
\examples{
Hilbert(6)
}
\keyword{array}
\keyword{algebra}

\eof
\name{LU-class}
\docType{class}
\alias{LU-class}
\alias{expand,LU-method}

\title{LU decompositions}
\description{The \code{"LU"} class is the class of LU decompositions of
  real matrices}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("LU", ...)}.
  More commonly the objects are created explicitly from calls of the form
  \code{lu(mm)} where \code{mm} is an object that inherits from the
  \code{"geMatrix"} class or as a side-effect of other functions applied
  to \code{"geMatrix"} objects.
}
\section{Slots}{
  \describe{
    \item{\code{x}:}{Object of class \code{"numeric"} The \code{"L"}
      (unit lower triangular) and \code{"U"} (upper triangular) factors
      of the original matrix.  These are stored in a packed format
      described in the Lapack manual.}
    \item{\code{Dim}:}{Object of class \code{"integer"} - the dimensions
     of the original matrix - must be an integer vector with exactly two
     non-negative values.}
    \item{\code{pivot}:}{Object of class \code{"integer"} - a vector of
      length \code{min(Dim)} that describes the permutation applied to
      the rows of the original matrix.  The contents of this vector are
      described in the Lapack manual.}
  }
}
\section{Methods}{
  \describe{
    \item{expand}{\code{signature(x = "LU")}: Produce the \code{"L"} and
    \code{"U"} factors as a named list of matrices.}
  }
}
% \references{}
% \author{}
% \note{}
\seealso{
  \code{\link{geMatrix-class}}, \code{\link{lu}}, \code{\link{expand}}
}
\examples{
mm = Matrix(rnorm(9), nrow = 3, ncol = 3)
mm
lum = lu(mm)
elu = expand(lum)
elu
elu$L %*% elu$U
}
\keyword{classes}
\keyword{algebra}

\eof
\name{Matrix-class}
\docType{class}
\alias{Matrix-class}
\alias{show,Matrix-method}
\title{Class "Matrix" Virtual class of Matrices}
\description{The \code{Matrix} class is a virtual class contained by all actual
  classes in the \code{Matrix} package.}
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "Matrix"}}
  }
}
%\references{}
\author{Douglas Bates \email{bates@stat.wisc.edu}}
%\note{}
\seealso{
  \code{\link{geMatrix-class}}, \code{\link{cscMatrix-class}}
}
%\examples{}
\keyword{classes}
\keyword{algebra}

\eof
\name{Matrix}
\alias{Matrix}
\title{Construct a Classed Matrix}
\usage{
Matrix(data=NA, nrow=1, ncol=1, byrow=FALSE, dimnames=NULL)
}
\description{
    Construct a Matrix of a class that inherits from \code{Matrix}.
}
\arguments{
  \item{data}{an optional numeric data vector or matrix.}
  \item{nrow}{the desired number of rows}
  \item{ncol}{the desired number of columns}
  \item{byrow}{logical. If \code{FALSE}
    (the default) the matrix is filled by columns, otherwise the matrix is
    filled by rows.}
  \item{dimnames}{A \code{\link{dimnames}} attribute for the matrix: a
    \code{list} of length 2.}
}
\value{
    Returns an \code{nrow} by \code{ncol} matrix of a class that
    inherits from \code{"Matrix"}. 
}
\details{
    If either of \code{nrow} or \code{ncol} is
    not given, an attempt is made to infer it from the length of
    \code{data} and the other parameter.

    Although it is sometime possible to mix unclassed matrices (created
    with \code{matrix}) with ones of class \code{"Matrix"}, it is much
    safer to always use carefully constructed ones of class
    \code{"Matrix"}.
}
\seealso{
    \code{\link{matrix}}.
}
\examples{
Matrix(0, 3, 2)             # a 3 by 2 matrix of zeros
Matrix(1:6, 3, 2)           # a 3 by 2 matrix
Matrix(1:6, nrow=3)   
Matrix(1:6, ncol=2)   
Matrix(1:9, nrow=3, dimnames =list(c("a", "b", "c"), c("A", "B", "C")))
}
\keyword{array}
\keyword{algebra}

\eof
\name{Schur}
\title{Schur Decomposition of a Matrix}
\usage{
Schur(x, vectors, \dots)
}
\alias{Schur}
%\alias{Schur.Matrix}
\description{
    Computes the Schur decomposition and eigenvalues of a square matrix.
}
\arguments{
  \item{x}{
    numeric or complex square Matrix inheriting from class
    \code{"Matrix"}. Missing values (NAs) are not allowed.
  }
  \item{vectors}{logical.  When \code{TRUE} (the default), the Schur
    vectors are computed.
  }
  \item{\dots}{further arguments passed to or from other methods.}      
}
\value{
  An object of class \code{c("schur.Matrix", "decomp")} whose
  attributes include the eigenvalues, the Schur quasi-triangular form
  of the matrix, and the Schur vectors (if requested).
}
\details{
  Based on the Lapack functions \code{dgeesx}
}
\section{BACKGROUND}{
  If \code{A} is a square matrix, then \code{A = Q T t(Q)}, where
  \code{Q} is orthogonal, and \code{T} is upper quasi-triangular
  (nearly triangular with either 1 by 1 or 2 by 2 blocks on the
  diagonal).
  The eigenvalues of \code{A} are the same as those of \code{T},
  which are easy to compute. The Schur form is used most often for
  computing non-symmetric eigenvalue decompositions, and for computing
  functions of matrices such as matrix exponentials.
}
\references{
  Anderson, E., et al. (1994).
  \emph{LAPACK User's Guide,}
  2nd edition, SIAM, Philadelphia.
}
\examples{
#Schur(Hilbert(9))              # Schur factorization (real eigenvalues)
#A <- Matrix(rnorm( 9*9, sd = 100), nrow = 9)
#schur.A <- Schur(A)
#mod.eig <- Mod(schur.A$values) # eigenvalue modulus
#schur.A
}
\keyword{algebra}

\eof
\name{ScotsSec}
\alias{ScotsSec}
\docType{data}
\title{Scottish secondary school scores}
\description{
  Scores attained by 3435 Scottish secondary school students on a
  standardized test taken at age 16.  Both the primary school and the
  secondary school that the student attended have been recorded.
}
\usage{data(ScotsSec)}
\format{
  A data frame with 3435 observations on the following 6 variables.
  \describe{
    \item{verbal}{The verbal reasoning score on a test taken by the
      students on entry to secondary school.}
    \item{attain}{The score attained on the standardized test taken at
      age 16.}
    \item{primary}{A factor indicating the primary school that the
      student attended.}
    \item{sex}{A factor with levels \code{M} and \code{F}}
    \item{social}{The student's social class on a numeric scale from low
      to high social class.}
    \item{second}{A factor indicating the secondary school that the
      student attended.}
  }
}
\details{
  These data are an example of cross-classified grouping factors.
}
\source{
  \url{http://multilevel.ioe.ac.uk/softrev/2lev-xc.html}
}
\references{
  Paterson, L. (1991). Socio economic status and educational attainment:
  a multidimensional and multilevel study. \emph{Evaluation and Research
    in Education} \bold{5}: 97-121.
}
\examples{
data(ScotsSec)
str(ScotsSec)
}
\keyword{datasets}

\eof
\name{coefGets}
\docType{genericFunction}
\alias{coef<-}
\alias{coef<--methods}
\alias{coef<-,pdCompSymm,numeric-method}
\alias{coef<-,pdDiag,numeric-method}
\alias{coef<-,pdIdent,numeric-method}
\alias{coef<-,pdLogChol,numeric-method}
\alias{coef<-,pdNatural,numeric-method}
\alias{coef<-,reStruct,numeric-method}
\alias{coef<-,ssclme,numeric-method}
\title{Assign parameters}
\description{
  A generic function to assign the parameter vector in an object.  For
  historical reasons parameters are accessed with \code{coef} and
  assigned with \code{coef<-}.
}
\usage{
coef(object, \dots) <- value
}
\arguments{
  \item{object}{An object that has a numeric parameter vector accessed
    by \code{coef}.}
  \item{\dots}{Additional arguments used by some methods.}
  \item{value}{A numeric vector of the same length as \code{coef(object)}.}
}
%\details{}
\value{
  \code{object} with an updated parameter vector
}
%\references{}
\author{Douglas Bates \email{bates@stat.wisc.edu}
  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
%\seealso{}
\examples{
m1 <- pdLogChol(~ age)
coef(m1) <- rnorm(3)
m1
}
\keyword{manip}

\eof
\name{corFactor}
\docType{genericFunction}
\alias{corFactor}
\title{Extract the correlation factor}
\description{
  A generic function to extract the factor of the correlation matrix of
  the object represented by \code{object}.
}
\usage{
corFactor(object, ...)
}
\arguments{
  \item{object}{an object that can be coerced to a correlation matrix factor}
  \item{\dots}{some methods for this generic may take additional,
    optional arguments}
}
%\details{}
\value{
  An object of class \code{corrfactor}.
}
%\references{}
\author{Douglas Bates \email{bates@stat.wisc.edu}
  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
%\seealso{}
\examples{
}
\keyword{models}

\eof
\name{corMatrix}
\docType{genericFunction}
\alias{corMatrix}
\alias{corMatrix,pdMat-method}
\title{Generate the correlation matrix}
\description{
  This generic function generates a correlation matrix from an object of
  a suitable class.

  This function is deprecated.  Use coersion to the \code{corrmatrix}
  class instead.
}
\usage{
corMatrix(object, ...)
} 
\arguments{
  \item{object}{An object of a suitable class}
  \item{\dots}{Some methods for this generic take additional, optional
    arguments.}
}
%\details{}
\value{
  An object of class \code{\link[lme4:corrmatrix-class]{corrmatrix}}.
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu} and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
\seealso{\code{\link{corrmatrix-class}}}
%\examples{}
\keyword{models}

\eof
\name{corrmatrix-class}
\docType{class}
\alias{corrmatrix-class}
\title{Class "corrmatrix"}
\alias{coerce,pdIdent,corrmatrix-method}
\alias{coerce,pdMat,corrmatrix-method}
\alias{coerce,pdNatural,corrmatrix-method}
\alias{coerce<-,pdNatural,corrmatrix-method}
\alias{coerce,pdmatrix,corrmatrix-method}
\description{A class of correlation matrices}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("corrmatrix", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"matrix"} - the actual
      correlation matrix}
    \item{\code{stdDev}:}{Object of class \code{"numeric"} giving the
      corresponding standard deviations }
  }
}
\section{Extends}{
Class \code{"matrix"}, from data part.
Class \code{"structure"}, by class "matrix".
Class \code{"array"}, by class "matrix".
Class \code{"vector"}, by class "matrix".
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "pdIdent", to = "corrmatrix")}: ... }
  }
}
\references{}
\author{Douglas Bates \email{bates@stat.wisc.edu}
  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
\examples{
}
\keyword{classes}

\eof
\name{cscMatrix-class}
\docType{class}
\alias{cscMatrix-class}
\alias{coerce,matrix,cscMatrix-method}
\alias{coerce,cscMatrix,tripletMatrix-method}
\alias{coerce,cscMatrix,matrix-method}
\alias{coerce,cscMatrix,geMatrix-method}
\alias{crossprod,cscMatrix,missing-method}
\alias{crossprod,cscMatrix,matrix-method}
\alias{crossprod,cscMatrix,numeric-method}
\alias{diag,cscMatrix-method}
\alias{dim,cscMatrix-method}
\alias{image,cscMatrix-method}
\alias{t,cscMatrix-method}
\title{Class "cscMatrix" compressed, sparse, column Matrix}
\description{The \code{cscMatrix} class is a class of sparse matrices in
  the compressed, sparse, column-oriented format.  In this
  implementation the non-zero elements in the columns are sorted into
  increasing row order.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("cscMatrix", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{p}:}{Object of class \code{"integer"} of pointers, one
      for each column, to the initial (zero-based) index of elements in
      the column.}
    \item{\code{i}:}{Object of class \code{"integer"} of length nnzero
      (number of non-zero elements).  These are the row numbers for
      each non-zero element in the matrix.}
    \item{\code{x}:}{Object of class \code{"numeric"} - the non-zero
      elements of the matrix.}
    \item{\code{nrow}:}{Object of class \code{"integer"} - the number of
      rows in the matrix.}
  }
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "matrix", to = "cscMatrix")}}
    \item{coerce}{\code{signature(from = "cscMatrix", to = "matrix")}}
    \item{coerce}{\code{signature(from = "cscMatrix", to = "tripletMatrix")}}
    \item{crossprod}{\code{signature(x = "cscMatrix", y = "missing")}
      returns \code{t(x) \%*\% x} as an \code{sscMatrix} object.}
    \item{crossprod}{\code{signature(x = "cscMatrix", y = "matrix")}: ... }
    \item{crossprod}{\code{signature(x = "cscMatrix", y = "numeric")}: ... }
    \item{diag}{\code{signature(x = "cscMatrix")}: returns the diagonal
      of \code{x}}
    \item{dim}{\code{signature(x = "cscMatrix")}: returns the dimensions
      of \code{x}}
    \item{image}{\code{signature(x = "cscMatrix")}: plots an image of
      \code{x} using the \code{\link[lattice]{levelplot}} function}
  }
}
%\references{}
%\author{}
%\note{}
\seealso{
  \code{\link{sscMatrix-class}}, \code{\link{tscMatrix-class}}
}
%\examples{}
\keyword{classes}
\keyword{algebra}

\eof
\name{expand}
\title{Expand a Decomposition into Factors}
\usage{
expand(x, \dots)
}
\alias{expand}
\alias{expand.default}
\description{
    Expands decompositions stored in compact form into factors.
}
\arguments{
    \item{x}{
	a matrix decomposition. 
    }
    \item{\dots}{further arguments passed to or from other methods.}
}
\value{
    the expanded decomposition.
}
\details{
    This is a generic function with special methods for different types
    of decompositions.
    Use \code{\link{methods}("expand")} to list all the methods for the
    \code{expand} generic.
}
\section{NOTE}{
    Factors for decompositions such as \code{lu} and \code{qr} can be
    stored in a compact form.
    The function \code{expand} allows all factors to be fully expanded. 
}
\seealso{
%    \code{\link{expand.lu.Matrix}}, \code{\link{expand.lu.Hermitian}},
%    \code{\link{expand.qr.Matrix}}, \code{\link{expand.eigen.Matrix}},
    \code{\link{facmul}}.
}
\examples{
library(Matrix)
x <- Matrix( 1:9, 3, 3)
\dontrun{
expand(qr(x))
}
}
\keyword{algebra}

\eof
\name{facmul}
\title{Multiplication by Decomposition Factors}
\usage{
facmul(x, factor, y, transpose, left, \dots)
}
\alias{facmul}
\alias{facmul.default}
\description{
    Performs multiplication by factors for certain decompositions (and
    allows explicit formation of those factors).
}
\arguments{
    \item{x}{
	a matrix decomposition. 
	No missing values or IEEE special values are allowed.
    }
    \item{factor}{
	an indicator for selecting a particular factor for multiplication.
    }
    \item{y}{
	a matrix or vector to be multiplied by the factor or its transpose.
	No missing values or IEEE special values are allowed.
    }
    \item{transpose}{
	a logical value.  When \code{FALSE} (the default) the factor is
	applied.  When \code{TRUE} the transpose of the factor is applied.
    }
    \item{left}{
	a logical value.  When \code{TRUE} (the default) the factor is
	applied from the left.  When \code{FALSE} the factor is applied
	from the right.
    }
    \item{...}{
	the method for \code{"qr.Matrix"} has additional arguments.
    }
}
\value{
    the product of the selected factor (or its transpose) and \code{y}
}
\section{NOTE}{
    Factors for decompositions such as \code{lu} and \code{qr} can be
    stored in a compact form.
    The function \code{facmul} allows multiplication without explicit
    formation of the factors, saving both storage and operations.
}
\references{
Golub, G., and Van Loan, C. F. (1989).
\emph{Matrix Computations,}
2nd edition, Johns Hopkins, Baltimore.
}
%  \seealso{
%      \code{\link{facmul.lu.Matrix}}, \code{\link{facmul.lu.Hermitian}}, \code{\link{facmul.qr.Matrix}}, \code{\link{expand}}.
%  }
\examples{
library(Matrix)
x <- Matrix(rnorm(9), 3, 3)
\dontrun{
qrx <- qr(x)                      # QR factorization of x
y <- rnorm(3)
facmul( qr(x), factor = "Q", y)   # form Q y
}
}
\keyword{array}
\keyword{algebra}

\eof
\name{geMatrix-class}
\docType{class}
\alias{geMatrix-class}
\alias{%*%,geMatrix,geMatrix-method}
\alias{Schur,geMatrix,logical-method}
\alias{Schur,geMatrix,missing-method}
\alias{coerce,matrix,geMatrix-method}
\alias{coerce,geMatrix,matrix-method}
\alias{crossprod,geMatrix,geMatrix-method}
\alias{crossprod,geMatrix,matrix-method}
\alias{crossprod,geMatrix,missing-method}
\alias{crossprod,geMatrix,numeric-method}
\alias{determinant,geMatrix,logical-method}
\alias{determinant,geMatrix,missing-method}
\alias{diag,geMatrix-method}
\alias{dim,geMatrix-method}
\alias{lu,geMatrix-method}
\alias{norm,geMatrix,missing-method}
\alias{norm,geMatrix,character-method}
\alias{rcond,geMatrix,missing-method}
\alias{rcond,geMatrix,character-method}
\alias{solve,geMatrix,matrix-method}
\alias{solve,geMatrix,missing-method}
\title{General S4 Matrix class}
\description{A general, numeric matrix in the S4 Matrix representation}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("geMatrix", ...)}
or, more commonly, by coercion from the \code{matrix} class.
}
\section{Slots}{
  \describe{
    \item{\code{x}:}{Object of class \code{"numeric"} - the numeric
      values contained in the matrix, in column-major order.}
    \item{\code{Dim}:}{Object of class \code{"integer"} - the dimensions
     of the matrix - must be an integer vector with exactly two
     non-negative values.}
    \item{\code{rcond}:}{Object of class \code{"numeric"} - an estimate
      of the reciprocal of the condition number, if it has been computed
      at some point.}
    \item{\code{factorization}:}{Object of class \code{"list"} - a list
      of factorizations of the matrix. }
  }
}
\section{Methods}{
  \describe{
    \item{Schur}{\code{signature(x = "geMatrix", vectors = "logical")}: ... }
    \item{Schur}{\code{signature(x = "geMatrix", vectors = "missing")}: ... }
    \item{coerce}{\code{signature(from = "geMatrix", to = "matrix")}: ... }
    \item{coerce}{\code{signature(from = "matrix", to = "geMatrix")}: ... }
    \item{coerce}{\code{signature(from = "matrix", to = "geMatrix")}}
    \item{crossprod}{\code{signature(x = "geMatrix", y = "geMatrix")}: ... }
    \item{crossprod}{\code{signature(x = "geMatrix", y = "matrix")}: ... }
    \item{crossprod}{\code{signature(x = "geMatrix", y = "missing")}: ... }
    \item{crossprod}{\code{signature(x = "geMatrix", y = "numeric")}: ... }
    \item{diag}{\code{signature(x = "geMatrix")}: ... }
    \item{dim}{\code{signature(x = "geMatrix")}: ... }
    \item{lu}{\code{signature(x = "geMatrix")}: ... }
    \item{norm}{\code{signature(x = "geMatrix", type = "character")}: ... }
    \item{norm}{\code{signature(x = "geMatrix", type = "missing")}: ... }
    \item{rcond}{\code{signature(x = "geMatrix", type = "character")}: ... }
    \item{rcond}{\code{signature(x = "geMatrix", type = "missing")}: ... }
    \item{solve}{\code{signature(a = "geMatrix", b = "geMatrix")}: ... }
    \item{solve}{\code{signature(a = "geMatrix", b = "missing")}: ... }
  }
}
%\references{}
%\author{}
%\note{}
\seealso{
  \code{\link{Matrix-class}}, \code{\link{trMatrix-class}}, \code{\link{syMatrix-class}}
}
%\examples{}
\keyword{classes}
\keyword{algebra}

\eof
\name{isInitialized}
\docType{genericFunction}
\alias{isInitialized}
\alias{isInitialized-methods}
\alias{isInitialized,pdBlocked-method}
\alias{isInitialized,pdCompSymm-method}
\alias{isInitialized,pdMat-method}
\alias{isInitialized,pdNatural-method}
%\alias{isInitialized,pdScalar-method}
\alias{isInitialized,lmeLevelList-method}
\title{Check for initialization}
\description{
  A generic function.  Methods for specific classes should return
  \code{TRUE} if \code{object} is initialized, otherwise \code{FALSE}.
}
\usage{
isInitialized(object)
}
\arguments{
  \item{object}{An object that may or may not be initialized.}
}
\value{
  A logical value indicating if the object is initialized.
}
\note{The name of this generic was changed from the original name,
  \code{isinitialized}, because that name is used in the \code{methods}
  package. }
\references{}
\author{Douglas Bates \email{bates@stat.wisc.edu}
  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
\examples{
}
\keyword{manip}

\eof
\name{lu}
\title{Triangular Decomposition of a Square Matrix}
\usage{
lu(x, \dots)
}
\alias{lu}
\description{
    Computes triangular decompositions of matrices.
}
\arguments{
    \item{x}{
	a matrix. No missing values or IEEE special values are allowed.
    }
    \item{\dots}{further arguments passed to or from other methods.}
}
\value{
    a representation of a triangular decomposition of \code{x}.
}
\details{
    This is a generic function with special methods for different types
    of matrices.
    Use \code{\link{methods}("lu")} to list all the methods for the
    \code{lu} generic.
}
\references{
Golub, G., and Van Loan, C. F. (1989).
\emph{Matrix Computations,}
2nd edition, Johns Hopkins, Baltimore.
}
\seealso{\code{\link{qr}}, \code{\link{chol}}}
\examples{
x <- Matrix( rnorm(9), 3, 3)
\dontrun{
lu(x)
}
}
\keyword{array}
\keyword{algebra}

\eof
\name{matrixGets}
\docType{genericFunction}
\alias{matrix<-}
\alias{matrix<--methods}
\alias{matrix<-,pdMat,matrix-method}
\title{Assign the matrix}
\description{
  This generic function assigns the matrix to an object of a suitable
  class, such as the \code{pdMat} class.

  This function is deprecated.  Use a coerced assignment instead.
}
\usage{
matrix(object) <- value
}
\arguments{
  \item{object}{An object of a suitable class}
  \item{value}{A matrix of a suitable size and family.}
}
\value{
  An object of the same class as \code{object}.
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu}
%  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
%\seealso{}
%\examples{}
\keyword{manip}
\keyword{algebra}
\keyword{array}
\keyword{methods}

\eof
\name{mm}
\alias{mm}
\docType{data}
\title{A sample sparse model matrix}
\description{
  A model matrix used in an example by Koenker and Ng.  This is a sparse
  matrix with 1850 rows and 712 columns but only 8758 non-zero entries.
  It is a \code{"cscMatrix"} object.
}
\usage{data(mm)}
%\details{}
%\source{}
\references{
  Roger Koenker and Pin Ng (2003), ``SparseM: A sparse matrix package
  for R'', \emph{J. of Statistical Software}, 8(6).
}
\examples{
data(mm)
data(y)
class(mm)
dim(mm)
str(mm)
str(y)
sparse.sol = solve(crossprod(mm), crossprod(mm, y))
str(sparse.sol)
}
\keyword{datasets}

\eof
\name{norm}
\alias{norm}
\title{
    Norm of a Matrix
}
\usage{norm(x, type, \dots) }
\description{
    Computes a matrix norm of \code{x} using Lapack.  The norm can be
    the one norm, the infinity norm, the Frobenius norm, or the maximum
    modulus among elements of a matrix, as determined by the value of
    \code{type}.
}
\arguments{
  \item{x}{
    a real or complex matrix.
  }
  \item{type}{
    A character indicating the type of norm desired.
    \code{"O"} or \code{"o"} or \code{"1"} specifies the one norm,
    (maximum absolute column sum);
    \code{"I"} or \code{"i"} specifies the infinity norm (maximum
    absolute row sum);
    \code{"F"} or \code{"f"} specifies the Frobenius norm (the
    Euclidean norm of \code{x} treated as if it were a vector);
    and \code{"M"} or \code{"m"} specifies the maximum modulus of
    all the elements in \code{x}. The default is \code{"O"}.
    
    Only the first character of \code{type[1]} is used.
  }
  \item{\dots}{further arguments passed to or from other methods.}
}
\value{
    A numeric value of class \code{"norm"}, representing the quantity
    chosen according to \code{type}.
}
\details{
    Based on the Lapack functions \code{dlange}, \code{dlansy}, \code{dlantr},
    \code{zlange},  \code{zlansy}, and \code{zlantr}.
}
\references{
    Anderson, E., et al. (1994).
    \emph{LAPACK User's Guide,}
    2nd edition, SIAM, Philadelphia.
}
\examples{
x <- Hilbert(9)
norm(x, "1")
norm(x, "I")
norm(x, "F")
norm(x, "M")
}
\keyword{algebra}

\eof
\name{pdBlocked-class}
\docType{class}
\alias{pdBlocked-class}
\alias{pdBlocked}
\title{Class "pdBlocked", blocked pd matrices}
\description{
  Block-diagonal positive definite matrices.
}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("pdBlocked", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{param}:}{Object of class \code{"list"} }
    \item{\code{form}:}{Object of class \code{"formula", from class "pdMat"}} \item{\code{Names}:}{Object of class \code{"character", from class "pdMat"} }
  }
}
\section{Extends}{
  Class \code{"pdMat"}, directly.
}
\section{Methods}{
  \describe{
    \item{Names}{\code{signature(object = "pdBlocked")}:}
    \item{Names<-}{\code{signature(object = "pdBlocked", value = "character")}:}
    \item{[}{\code{signature(x = "pdBlocked")}: }
    \item{coef}{\code{signature(object = "pdBlocked")}: }
    \item{coef<-}{\code{signature(object = "pdBlocked", value = "ANY")}: }
    \item{corMatrix}{\code{signature(object = "pdBlocked")}:}
    \item{formula}{\code{signature(x = "pdBlocked")}:}
    \item{isInitialized}{\code{signature(object = "pdBlocked")}:}
    \item{logDet}{\code{signature(object = "pdBlocked", covariate = "missing")}:}
    \item{matrix<-}{\code{signature(object = "pdBlocked", value = "matrix")}: }
    \item{pdFactor}{\code{signature(object = "pdBlocked")}: }
    \item{solve}{\code{signature(a = "pdBlocked", b = "missing")}:}
    \item{summary}{\code{signature(object = "pdBlocked")}:}
  }
}
%\references{}
\author{Douglas Bates \email{bates@stat.wisc.edu}
  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\seealso{}
%\examples{}
\keyword{classes}

\eof
\name{pdCompSymm-class}
\docType{class}
\alias{pdCompSymm-class}
\alias{pdCompSymm}
\alias{pdCompSymm,formula,missing,missing,missing-method}
\title{Class "pdCompSymm"}
\description{A class of parameterized positive-definite symmetric
  matrices that have compound symmetry.  That is, the diagonal entries
  are constant and the off-diagonal entries are constant.}
\section{Objects from the Class}{
  Objects can be created by calls of the form
  \code{new("pdCompSymm", ...)} or
  by calls to the constructor \code{pdCompSymm(...)}
}
\section{Slots}{
  \describe{
    \item{\code{param}:}{Object of class \code{"numeric"} - a parameter
      vector of length 2}
    \item{\code{ncol}:}{Object of class \code{"integer"} - the number of
      columns (and rows) in the matrix.}
    \item{\code{form}:}{Object of class \code{"formula", from class
	"pdMat"} - an optional formula relating the object to a model matrix. }
    \item{\code{Names}:}{Object of class \code{"character", from class
	"pdMat"} - dimnames for the matrix}
  }
}
\section{Extends}{
Class \code{"pdMat"}, directly.
}
\section{Methods}{
  \describe{
    \item{coef}{\code{signature(x = "pdCompSymm")}: get the parameter vector }
    \item{coef<-}{\code{signature(object = "pdCompSymm", value =
	"numeric")}: set the parameter vector}
    \item{coef<-}{\code{signature(object = "pdCompSymm", value =
	"matrix")}: set the parameter vector from a model matrix}
    \item{coerce}{\code{signature(from = "pdCompSymm", to = "matrix")}:
      get the positive-definite symmetric matrix represented by the object.}
    \item{corMatrix}{\code{signature(object = "pdCompSymm")}: get the
      matrix represented by the object as a correlation matrix (with
      standard deviations)}
    \item{dim}{\code{signature(x = "pdCompSymm")}: get the dimensions of
      the matrix represented by the object.}
    \item{isInitialized}{\code{signature(object = "pdCompSymm")}: check
      if the object has been initialized.}
    \item{logDet}{\code{signature(object = "pdCompSymm", covariate =
	"missing")}: get the logarithm of the determinant of the matrix}
    \item{pdFactor}{\code{signature(object = "pdCompSymm")}: get a
      square root factor of the matrix represented by the object.}
    \item{pdMatrix}{\code{signature(object = "pdCompSymm", factor =
	"logical")}: get the positive-definite symmetric matrix
	represented by the object.}
    \item{summary}{\code{signature(object = "pdCompSymm")}:}
  }
}
\author{Douglas Bates \email{bates@stat.wisc.edu}
  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
\seealso{}
\examples{
}
\keyword{classes}

\eof
\name{pdDiag-class}
\docType{class}
\alias{pdDiag-class}
\alias{pdDiag}
\alias{pdDiag,formula,missing,missing,missing-method}
\alias{solve,pdDiag,missing-method}
\title{Class "pdDiag"}
\description{A class of parameterized diagonal positive-definite
  matrices.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("pdDiag", ...)} or
  by calls to the constructor function \code{pdDiag}.
}
\section{Slots}{
  \describe{
    \item{\code{form}:}{Object of class \code{"formula", from class
	"pdMat"} an optional formula used to generate the object.}
    \item{\code{Names}:}{Object of class \code{"character", from class
	"pdMat"} row (and column) names for the matrix.}
    \item{\code{param}:}{Object of class \code{"numeric", from class
	"pdMat"} the unconstrained, numeric parameter vector of length
      \code{Ncol}.  The elements of the parameter vector are the
      logarithms of the square roots of the diagonal elements of the matrix. }
    \item{\code{Ncol}:}{Object of class \code{"integer", from class
	"pdMat"} the number of rows and columns in the matrix. }
    \item{\code{factor}:}{Object of class \code{"matrix", from class
	"pdMat"} a square-root factor of the matrix - also a diagonal
      matrix.}
    \item{\code{logDet}:}{Object of class \code{"numeric", from class
	"pdMat"} the logarithm of the absolute value of the determinant
      of the factor.}
  }
}
\section{Extends}{
Class \code{"pdMat"}, directly.
}
\section{Methods}{
  \describe{
    \item{coef}{\code{signature(x = "pdDiag")}: extract the parameters.}
    \item{coef<-}{\code{signature(object = "pdDiag", value =
	"numeric")}: assign the parameters.}
    \item{coerce}{\code{signature(from = "pdDiag", to = "matrix")}:
      extract the matrix.}
    \item{corMatrix}{\code{signature(object = "pdDiag")}: extract the
      correlation matrix. }
    \item{dim}{\code{signature(x = "pdDiag")}: extract the dimensions.}
    \item{isInitialized}{\code{signature(object = "pdDiag")}: check if initialized.}
    \item{logDet}{\code{signature(object = "pdDiag", covariate =
	"missing")}: return the logarithm of the determinant of the matrix.}
    \item{solve}{\code{signature(a = "pdDiag", b = "missing")}: invert
      the matrix returning a \code{pdDiag} object.}
  }
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu} and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
\seealso{\code{\link{pdMat-class}}}
\examples{
}
\keyword{classes}

\eof
\name{pdFactor}
\docType{methods}
\docType{genericFunction}
\alias{pdFactor}
\alias{pdFactor-methods}
\alias{pdFactor,pdMat-method}
\title{Square-root factor}
\description{This generic function extracts the square-root factor of
  the positive-definite matrix represented by \code{object}. Letting
  \eqn{\Sigma}{S} denote a positive-definite matrix, a square-root
  factor of \eqn{\Sigma}{S} is any square matrix \eqn{L}{L} such that
  \eqn{\Sigma = L'L}{S = L'L}. This function extracts \eqn{L}.

  This function is deprecated.  Use coersion to the \code{pdfactor}
  class instead.
}
\usage{
pdFactor(object)
}
\arguments{
 \item{object}{an object inheriting from class \code{pdMat}, representing
   a positive definite matrix, which must have been initialized
   (i.e. \code{length(coef(object)) > 0}).} 
}
\value{
  A \code{pdfactor} object.
}
\seealso{\code{\link{pdMat-class}}, \code{\link{pdfactor-class}}}
%\examples{}
\keyword{models}

\eof
\name{pdIdent-class}
\docType{class}
\alias{pdIdent-class}
\alias{pdIdent}
\alias{solve,pdIdent,missing-method}
\alias{pdIdent,formula,missing,missing,missing-method}
\title{Class "pdIdent"}
\description{A class of parameterized positive-definite
  matrices that are multiples of the identity matrix.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("pdIdent", ...)} or
  by calls to the constructor function \code{pdIdent}.
}
\section{Slots}{
  \describe{
    \item{\code{form}:}{Object of class \code{"formula", from class
	"pdMat"} an optional formula used to generate the object.}
    \item{\code{Names}:}{Object of class \code{"character", from class
	"pdMat"} row (and column) names for the matrix.}
    \item{\code{param}:}{Object of class \code{"numeric", from class
	"pdMat"} the unconstrained, numeric parameter vector of length
      \code{Ncol}.  The elements of the parameter vector are the
      logarithms of the square roots of the diagonal elements of the matrix. }
    \item{\code{Ncol}:}{Object of class \code{"integer", from class
	"pdMat"} the number of rows and columns in the matrix. }
    \item{\code{factor}:}{Object of class \code{"matrix", from class
	"pdMat"} a square-root factor of the matrix - also a diagonal
      matrix.}
    \item{\code{logDet}:}{Object of class \code{"numeric", from class
	"pdMat"} the logarithm of the absolute value of the determinant
      of the factor.}
  }
}
\section{Extends}{
Class \code{"pdMat"}, directly.
}
\section{Methods}{
  \describe{
    \item{coef}{\code{signature(x = "pdIdent")}: extract the parameters.}
    \item{coef<-}{\code{signature(object = "pdIdent", value =
	"numeric")}: assign the parameters.}
    \item{coerce}{\code{signature(from = "pdIdent", to = "matrix")}:
      extract the matrix.}
    \item{corMatrix}{\code{signature(object = "pdIdent")}: extract the
      correlation matrix. }
    \item{dim}{\code{signature(x = "pdIdent")}: extract the dimensions.}
    \item{isInitialized}{\code{signature(object = "pdIdent")}: check if initialized.}
    \item{logDet}{\code{signature(object = "pdIdent", covariate =
	"missing")}: return the logarithm of the determinant of the matrix.}
    \item{solve}{\code{signature(a = "pdIdent", b = "missing")}: invert
      the matrix returning a \code{pdIdent} object.}
  }
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu} and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
\seealso{\code{\link{pdMat-class}}}
\examples{
}
\keyword{classes}

\eof
\name{pdLogChol-class}
\docType{class}
\alias{pdLogChol-class}
\alias{pdLogChol}
\alias{solve,pdLogChol,missing-method}
\alias{pdLogChol,formula,missing,missing,missing-method}
\title{Class "pdLogChol", positive-definite matrices}
\description{A class of general, positive-definite
  symmetric matrices parameterized by the non-zero elements in the
  Cholesky decomposition.  The diagonal elements are represented by
  their logarithms in the first \code{q} positions of the parameter
  vector.  The strict upper triangle of the factor is in the last
  \code{q(q-1)/2} positions.}
\section{Objects from the Class}{
  Objects of class \code{pdLogChol} can be created by calls of the form
  \code{new("pdLogChol", ...)} or by the generic constructor function
  \code{pdLogChol}.  Frequently the constructor is given a formula only,
  creating an uninitialized \code{pdLogChol} object which is later
  assigned a value.

  \code{pdLogChol} objects are primarily used to represent the
  variance-covariance matrix or the precision matrix of random-effects
  terms in mixed-effects models.
}
\section{Slots}{
  \describe{
    \item{\code{form}:}{Object of class \code{"formula", from class
	"pdMat"}, a formula for the object}
    \item{\code{Names}:}{Object of class \code{"character", from class
	"pdMat"}, names for the rows (and columns) of the
      positive-definite matrix.}
    \item{\code{param}:}{Object of class \code{"numeric", from class
	"pdMat"}, a parameter vector of length
      \eqn{[q(q+1)]/2}{[q(q+1)]/2} where \eqn{q}{q} is \code{Ncol}, the
      number of columns (and rows) in the positive-definite matrix.}
    \item{\code{Ncol}:}{Object of class \code{"integer", from class
	"pdMat"}, number of columns (and rows) in the positive-definite
      matrix.}
    \item{\code{factor}:}{Object of class \code{"matrix", from class
	"pdMat"}, a square root factor of the positive-definite matrix.}
    \item{\code{logDet}:}{Object of class \code{"numeric", from class
	"pdMat"} the logarithm of the absolute value of the determinant
      of the square root factor or, equivalently, half the logarithm of
      the determinant of the positive-definite matrix.}
  }
}
\section{Extends}{
Class \code{"pdMat"}, directly.
}
\section{Methods}{
  \describe{
    \item{EMupdate<-}{\code{signature(x = "pdLogChol", nlev = "numeric",
	value = "matrix")}: update the \code{pdLogChol} object in the EM
      algorithm for a mixed-effects model.}
    \item{LMEgradient}{\code{signature(x = "pdLogChol", A = "matrix",
	nlev = "numeric")}: evaluate the gradient of the log-likelihood
      in a linear mixed-effects model.}
    \item{coef<-}{\code{signature(object = "pdLogChol", value =
	"numeric")}: assign the parameter.}
    \item{coerce}{\code{signature(from = "pdLogChol", to = "pdmatrix")}:
      extract the positive-definite matrix represented by the object.}
    \item{pdgradient}{\code{signature(x = "pdLogChol")}: the gradient of
      the positive definite matrix with respect to the parameter vector.}
    \item{solve}{\code{signature(a = "pdLogChol", b = "missing")}: a
      \code{pdLogChol} object representing the inverse of the
      positive-definite matrix represented by this object.}
    \item{summary}{\code{signature(object = "pdLogChol")}: summarize the
      object.}
  }
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu}
%  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
\seealso{\code{\link{pdMat-class}}}
\examples{
m1 <- pdLogChol(~ age)
coef(m1) <- rnorm(3)
print(m1)
solve(m1)
}
\keyword{classes}

\eof
\name{pdMat-class}
\docType{class}
\alias{pdMat-class}
\alias{coef,pdMat-method}
\alias{coerce,pdMat,pdfactor-method}
\alias{coerce,pdMat,matrix-method}
\alias{coerce<-,pdMat,matrix-method}
\alias{coerce<-,pdMat,pdfactor-method}
\alias{dim,pdMat-method}
\alias{formula,pdMat-method}
\alias{names,pdMat-method}
\alias{names<-,pdMat-method}
\alias{show,pdMat-method}
\alias{solve,pdMat-method}
\alias{solve,pdMat,missing-method}
\alias{summary,pdMat-method}
\title{Class pdMat, positive-definite matrices}
\description{A virtual class of parameterized positive-definite
  symmetric matrices.  This class describes the slots and methods that
  actual classes of positive-definite matrices are expected to
  incorporate.  Some classes that inherit from \code{pdMat} have
  additional slots and methods.}
\section{Objects from the Class}{
  Objects of class \code{pdMat} are not constructed directly; only
  objects from classes that inherit from \code{pdMat} are constructed.
}
\section{Slots}{
  \describe{
    \item{\code{form}:}{Object of class \code{"formula"}, holds the
      formula for the object }
    \item{\code{Names}:}{Object of class \code{"character"} holding the
      names of the rows (and columns) of the positive-definite symmetric
      matrix represented by the object.}
    \item{\code{param}:}{\code{"numeric"} - the parameter vector.}
    \item{\code{Ncol}:}{\code{"integer"} - the number of columns (and
      rows) in the matrix.}
    \item{\code{factor}:}{\code{"matrix"} - a square-root factor of the
      matrix.}
    \item{\code{logDet}:}{\code{"numeric"} - the logarithm of the
      determinant of the factor.}
  }
}

\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "pdMat", to = "pdfactor")}:
      extract a square-root factor of the matrix represented by the
      object.  This factor has a \code{logDet} slot giving the
      logarithm of its determinant.  In the case of \code{pdLogChol}
      these are both scalars and the \code{logDet} attribute is the
      logarithm of the absolute value of the factor.}
    \item{corMatrix}{\code{signature(object = "pdMat")}: Extract the
      correlation matrix corresponding to the positive-definite matrix
      represented by the object.  This method is present for back
      compatibility only.  The preferred way of extracting the
      correlation matrix is to coerce the object to the
      \code{"corrmatrix"} class.}
    \item{dim}{\code{signature(x = "pdMat")}: the dimensions of the
      positive-definite matrix represented by the object.} 
    \item{formula}{\code{signature(x = "pdMat")}: extract the formula }
    \item{isInitialized}{\code{signature(object = "pdMat")}:
      \code{TRUE} if the object has been initialized, otherwise \code{FALSE}.}
    \item{logDet}{\code{signature(object = "pdMat", covariate =
	"missing")}: the logarithm of the determinant of the factor of
      the positive-definite matrix represented by the object.} 
    \item{names}{\code{signature(x = "pdMat")}: extract a vector of
      names, which are both the column names and the row names of the
      positive-definite matrix represented by the object.}
    \item{names<-}{\code{signature(x = "pdMat")}: assign the names,}
    \item{pdFactor}{\code{signature(object = "pdMat")}: Extract the
      square root factor of positive-definite symmetric matrix
      represented by the object.  This method is present for back
      compatibility only.  The preferred way of extracting the factor is
      to coerce the object to the \code{"pdfactor"} class.}
    \item{pdMatrix}{\code{signature(object = "pdMat")}: Extract the
      positive-definite symmetric matrix represented by the object.
      This method is present for back compatibility only.  The preferred
      way of extracting the positive-definite symmetric matrix is to
      coerce the object to the \code{"pdmatrix"} class.}
    \item{show}{\code{signature(x = "pdMat")}: show the object.}
    \item{solve}{\code{signature(a = "pdMat", b = "missing")}: Create an
      object of the same class representing the inverse of the
      positive-definite matrix.}
    \item{summary}{\code{signature(object = "pdMat")}:}
  }
}
\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu}
%  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
\note{
  \code{pdMat} objects are primarily used to represent the variance-covariance
  matrix or the precision matrix of random-effects terms in
  mixed-effects models.  Frequently they are constructed from a formula
  only in the call to the mixed-effects modelling function then assigned
  a value as part of the initialization of the model.
}
\seealso{\code{\link{pdCompSymm-class}}, \code{\link{pdDiag-class}},
  \code{\link{pdLogChol-class}}, \code{\link{pdIdent-class}}
}
%\examples{}
\keyword{classes}

\eof
\name{pdMatrix}
\docType{methods}
\docType{genericFunction}
\alias{pdMatrix}
\alias{pdMatrix-methods}
\alias{pdMatrix,pdMat-method}
\title{Return the positive-definite matrix}
\description{This generic function extracts the positive-definite matrix
  represented by \code{object}.

  This function is deprecated.  Use coersion to the \code{pdmatrix}
  class instead.
}
\usage{
pdMatrix(object)
}
\arguments{
 \item{object}{an object inheriting from class \code{pdMat}, representing
   a positive definite matrix, which must have been initialized
   (i.e. \code{length(coef(object)) > 0}).} 
}
\value{
  A \code{pdmatrix} object.
}
\seealso{\code{\link{pdmatrix-class}}, \code{\link{pdMat-class}}}
%\examples{}
\keyword{models}

\eof
\name{pdNatural-class}
\docType{class}
\alias{pdNatural-class}
\alias{pdNatural}
\alias{pdNatural,formula,missing,missing,missing-method}
\alias{pdNatural,pdMat,missing,missing,missing-method}
\alias{solve,pdNatural,missing-method}
\title{Class "pdNatural", positive-definite matrices}
\description{A class of general, positive-definite
  symmetric matrices parameterized by the logarithm of the diagonal
  elements and Fisher's z transformation of the correlations.}
\section{Objects from the Class}{

  Objects can be created by calls of the form \code{new("pdNatural",
    ...)} or by the generic constructor function \code{pdNatural}.
  Frequently the constructor is given a formula only, creating an
  uninitialized \code{pdNatural} object which is later assigned a
  value.

  \code{pdNatural} objects are primarily used to represent the
  variance-covariance matrix or the precision matrix of random-effects
  terms in mixed-effects models.
}
\section{Slots}{
  \describe{
    \item{\code{param}:}{Object of class \code{"numeric", from class
	"pdMat"}, a parameter vector of length
      \eqn{[q(q+1)]/2}{[q(q+1)]/2} where \eqn{q}{q} is the number of
      rows (and columns) in the positive-definite matrix.}
    \item{\code{form}:}{Object of class \code{"formula", from class
	"pdMat"}, a formula for the object}
    \item{\code{Names}:}{Object of class \code{"character", from class
	"pdMat"}, names for the rows (and columns) of the
      positive-definite matrix.}
  }
}
\section{Extends}{
Class \code{"pdMat"}, directly.
}
\section{Methods}{
  \describe{
    \item{EMupdate<-}{\code{signature(x = "pdNatural", nlev = "numeric",
	value = "matrix")}: update the \code{pdNatural} object in the EM
      algorithm for a mixed-effects model.}
    \item{LMEgradient}{\code{signature(x = "pdNatural", A = "matrix",
	nlev = "numeric")}: evaluate the gradient of the log-likelihood
      in a linear mixed-effects model.}
    \item{coef}{\code{signature(object = "pdNatural")}: extract the
      parameter.}
    \item{coef<-}{\code{signature(object = "pdNatural", value =
	"numeric")}: assign the parameter.}
    \item{coerce}{\code{signature(from = "pdNatural", to = "pdmatrix")}:
      extract the positive-definite matrix represented by the object.}
    \item{coerce}{\code{signature(from = "pdNatural", to = "pdfactor")}:
      extract a square-root factor of the matrix represented by the
      object.  This factor has a \code{logDet} attribute giving the
      logarithm of its determinant.  In the case of \code{pdNatural}
      these are both scalars and the \code{logDet} attribute is the
      logarithm of the absolute value of the factor.}
    \item{dim}{\code{signature(x = "pdNatural")}: the dimensions of the
      positive-definite matrix represented by the object.} 
    \item{isInitialized}{\code{signature(object = "pdNatural")}: a
      logical scalar indicating if the object is initialized. }
    \item{logDet}{\code{signature(object = "pdNatural", covariate =
	"missing")}: the logarithm of the determinant of the factor of
      the positive-definite matrix represented by the object.} 
    \item{pdgradient}{\code{signature(x = "pdNatural")}: the gradient of
      the positive definite matrix with respect to the parameter vector.}
    \item{solve}{\code{signature(a = "pdNatural", b = "missing")}: a
      \code{pdNatural} object representing the inverse of the
      positive-definite matrix represented by this object.}
    \item{summary}{\code{signature(object = "pdNatural")}: summarize the
      object.}
  }
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu}
%  and Saikat DebRoy \email{saikat@stat.wisc.edu}}
\seealso{\code{\link{pdMat-class}}}
%\examples{}
\keyword{classes}

\eof
\name{pdfactor-class}
\docType{class}
\alias{pdfactor-class}
\title{Factors of positive-definite matrices}
\description{If \eqn{\Sigma}{S} is a positive-definite matrix then any
  square matrix \eqn{L}{L} such that \eqn{\Sigma = L'L}{S = L'L} is said
  to be a square-root factor of \eqn{\Sigma}{S}.  The \code{pdfactor}
  class is the class of such matrices.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("pdfactor",
    ...)}.  More frequently they are created by coercing a \code{pdMat}
  or \code{pdmatrix} object to the \code{pdfactor} class.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{\code{"matrix"}: the factor itself, a numeric,
      square matrix}
    \item{\code{logDet}:}{\code{"numeric"}: the logarithm of the
      absolute value of the determinant of the factor.}
  }
}
\section{Extends}{
Class \code{"matrix"}, from data part.
Class \code{"structure"}, by class "matrix".
Class \code{"array"}, by class "matrix".
Class \code{"vector"}, by class "matrix".
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "pdIdent", to = "pdfactor")}:
      extract the pdfactor from a \code{pdIdent} object.}
  }
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu} and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
\seealso{\code{\link{pdMat-class}}, \code{\link{pdmatrix-class}}}
%\examples{}
\keyword{classes}

\eof
\name{pdmatrix-class}
\docType{class}
\alias{pdmatrix-class}
\alias{coerce,matrix,pdmatrix-method}
\alias{coerce,pdCompSymm,pdmatrix-method}
\alias{coerce,pdDiag,pdmatrix-method}
\alias{coerce,pdIdent,pdmatrix-method}
\alias{coerce,pdLogChol,pdmatrix-method}
\alias{coerce,pdMat,pdmatrix-method}
\alias{coerce,pdNatural,pdmatrix-method}
\alias{coerce,pdfactor,pdmatrix-method}
\alias{coerce,pdmatrix,pdfactor-method}
\alias{coerce<-,pdDiag,pdmatrix-method}
\alias{coerce<-,pdIdent,pdmatrix-method}
\alias{coerce<-,pdLogChol,pdmatrix-method}
\alias{coerce<-,pdMat,pdmatrix-method}
\alias{coerce<-,pdNatural,pdmatrix-method}
\alias{coerce<-,pdmatrix,pdfactor-method}
\title{Positive-definite matrices }
\description{The class of positive-definite, symmetric matrices.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("pdmatrix", ...)}.
  More frequently they are created by coercing a \code{pdMat}
  object to the \code{pdmatrix} class.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"matrix"}, which should
      be a numeric matrix.}
  }
}
\section{Extends}{
  Class \code{"matrix"}, from data part.
  Class \code{"structure"}, by class "matrix".
  Class \code{"array"}, by class "matrix".
  Class \code{"vector"}, by class "matrix".
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "pdDiag", to = "pdmatrix")}: extract the positive-definite matrix }
    \item{coerce}{\code{signature(from = "pdIdent", to = "pdmatrix")}:
      extract the positive-definite matrix}
    \item{coerce}{\code{signature(from = "pdLogChol", to = "pdmatrix")}:
      extract the positive-definite matrix}
    \item{coerce}{\code{signature(from = "pdNatural", to = "pdmatrix")}:
      extract the positive-definite matrix}
%    \item{coerce}{\code{signature(from = "pdScalar", to = "pdmatrix")}:
%      extract the positive-definite matrix}
    \item{coerce}{\code{signature(from = "matrix", to = "pdmatrix")}:
      create a \code{pdmatrix} object from a matrix (does not check for
      symmetry or positive-definiteness)}
    \item{coerce}{\code{signature(from = "pdfactor", to = "pdmatrix")}:
      create a positive-definite matrix as the crossproduct of the factor.}
    \item{coerce}{\code{signature(from = "pdmatrix", to = "pdfactor")}:
      convert a \code{pdmatrix} object to its Cholesky factor}
  }
}
%\references{}
%\author{Douglas Bates \email{bates@stat.wisc.edu} and Saikat DebRoy \email{saikat@stat.wisc.edu}}
%\note{}
\seealso{\code{\link{pdfactor-class}}, \code{\link{pdMat-class}}}
%\examples{}
\keyword{classes}

\eof
\name{poMatrix-class}
\docType{class}
\alias{poMatrix-class}
\alias{rcond,poMatrix,character-method}
\alias{rcond,poMatrix,missing-method}
\alias{chol,poMatrix-method}
\alias{chol,poMatrix,ANY-method}
\alias{determinant,poMatrix,logical-method}
\alias{solve,poMatrix,geMatrix-method}
\alias{solve,poMatrix,matrix-method}
\alias{solve,poMatrix,missing-method}
\alias{solve,poMatrix,numeric-method}
\title{Positive semi-definite, dense, real matrices}
\description{The \code{"poMatrix"} class is the class of
  positive-semidefinite symmetric matrices in non-packed storage. Only the
  upper triangle or the lower triangle is required to be available.}
\section{Objects from the Class}{Objects can be created by calls of the
  form \code{new("poMatrix", ...)} or from \code{crossprod} applied to
  an \code{"geMatrix"} object.}
\section{Slots}{
  \describe{
    \item{\code{uplo}:}{Object of class \code{"character"}. Must be
      either "U", for upper triangular, and "L", for lower triangular.}
    \item{\code{x}:}{Object of class \code{"numeric"}. The numeric
      values that constitute the matrix, stored in column-major order.}
    \item{\code{Dim}:}{Object of class \code{"integer"}. The dimensions
      of the matrix which must be a two-element vector of non-negative
      integers.}
    \item{\code{rcond}:}{Object of class \code{"numeric"}. A named
      numeric vector of reciprocal condition numbers in either the
      1-norm \code{"O"} or the infinity norm \code{"I"}.}
    \item{\code{factorization}:}{Object of class \code{"list"}.  A named
      list of factorizations that have been computed for the matrix.}
  }
}
\section{Extends}{
Class \code{"syMatrix"}, directly.
Class \code{"geMatrix"}, by class \code{"syMatrix"}.
Class \code{"Matrix"}, by class \code{"syMatrix"}.
}
\section{Methods}{
  \describe{
    \item{chol}{\code{signature(x = "poMatrix")}:
      Returns (and stores) the Cholesky decomposition of the matrix
      \code{x}.}
    \item{rcond}{\code{signature(x = "poMatrix", type = "character")}:
      Returns (and stores) the reciprocal of the condition number of
      \code{x}.  The \code{type} can be \code{"O"} for the
      one-norm (the default) or \code{"I"} for the infinity-norm.  For
      symmetric matrices the result does not depend on the type.}
    \item{solve}{\code{signature(a = "poMatrix", b = "missing")}:
      Return the inverse of \code{a}.}
    \item{solve}{\code{signature(a = "poMatrix", b = "numeric")}:
      Solve the linear system defined by \code{a} and \code{b}, where
      \code{b} can be a numeric vector, or a matrix, or a geMatrix
      object.  The Cholesky decomposition of \code{a} is calculated (if
      needed) while solving the system.}
  }
}
%\references{}
%\author{}
\seealso{
  \code{\link{syMatrix-class}}, \code{\link{geMatrix-class}},
  \code{\link{Matrix}}, \code{\link{rcond}}, \code{\link{chol}},
  \code{\link{solve}}, \code{\link{crossprod}}
}
%\examples{}
\keyword{classes}
\keyword{algebra}

\eof
\name{rcond}
\title{Estimate the Reciprocal Condition Number}
\usage{
rcond(x, type, \dots)
}
\alias{rcond}
%\alias{rcond.default}
%\alias{rcond.Matrix}
\description{
  Estimate the reciprocal of the condition number of a matrix.
}
\arguments{
  \item{x}{
    a matrix. No missing values or IEEE special values are allowed.
  }
  \item{type}{
    Character indicating the type of norm to be used in the estimate.
    The default is \code{"O"} for the 1-norm.  The other possible value is
    \code{"I"} for the infinity norm.
  }
  \item{\dots}{further arguments passed to or from other methods.}
}
\value{
    An estimate of the reciprocal condition number of \code{x}.
}
\section{BACKGROUND}{
    The condition number of a matrix is the product of the matrix and
    the norm of its inverse (or pseudo-inverse if the matrix is not
    square).
    Since it can take on values between 1 and infinity, inclusive, it
    can be viewed as a measure of how close a matrix is to being rank
    deficient.
    It can also be viewed as a factor by which errors in solving linear
    systems with this matrix as coefficient matrix could be magnified.

    Condition numbers are usually estimated, since exact computation is
    costly in terms of floating-point operations.
    An (over) estimate of reciprocal condition number is given, since by
    doing so overflow is avoided.
    Matrices are well-conditioned if the reciprocal condition number is
    near 1 and ill-conditioned if it is near zero.
}
\references{
Golub, G., and Van Loan, C. F. (1989).
\emph{Matrix Computations,}
2nd edition, Johns Hopkins, Baltimore.
}
\examples{
x <- Matrix(rnorm(9), 3, 3)
rcond(x)
rcond(Hilbert(9))  # should be about 9.1e-13
}
\keyword{array}
\keyword{algebra}

\eof
\name{sscChol-class}
\docType{class}
\alias{sscChol-class}
\title{Cholesky decompositions of sscMatrix objects}
\description{The class of Cholesky decompositions of symmetric, sparse
  column matrices from the \code{"sscMatrix"} class.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("sscChol", ...)}
but are more commonly created from \code{chol} applied to an
\code{sscMatrix} object.
}
\section{Slots}{
  \describe{
    \item{\code{perm}:}{Object of class \code{"integer"} giving the
      permutation of the rows and columns chosen to minimize fill-in.
      If pivoting has not been applied this will be an integer vector of
      length 0.}
    \item{\code{iperm}:}{Object of class \code{"integer"} - the inverse
      permutation to the \code{perm} slot.}
    \item{\code{diag}:}{A character object indicating if the triangular
      matrix is unit triangular or not.  This slot is inherited from the
      \code{"tscMatrix"} class.  It is always \code{"N"} for this class.}
    \item{\code{uplo}:}{A character object indicating if the upper
      triangle (\code{"U"} or \code{"u"}) or the lower triangle
      (\code{"L"} or \code{"l"}) is stored.  At present only the lower
      triangle form is allowed.}
    \item{\code{p}:}{Object of class \code{"integer"} of pointers, one
      for each column, to the initial (zero-based) index of elements in
      the column.}
    \item{\code{i}:}{Object of class \code{"integer"} of length nnzero
      (number of non-zero elements).  These are the row numbers for
      each non-zero element in the matrix.}
    \item{\code{x}:}{Object of class \code{"numeric"} - the non-zero
      elements of the matrix.}
    \item{\code{factorization}:}{Object of class \code{"list"} - a list
      of factorizations of the matrix. }
    \item{\code{Dim}:}{Object of class \code{"integer"} - the dimensions
     of the matrix - must be an integer vector with exactly two
     non-negative values.}
  }
}
\section{Extends}{
Class \code{"tscMatrix"}, directly.
Class \code{"cscMatrix"}, by class \code{"tscMatrix"}.
}
\section{Methods}{
No methods defined with class "sscChol" in the signature.
}
%\references{}
%\author{}
%\note{}
\seealso{
  \code{\link{cscMatrix-class}}
}
%\examples{}
\examples{
data(mm)
xpx = crossprod(mm)
str(xpx)
str(chol(xpx))
}
\keyword{classes}
\keyword{algebra}

\eof
\name{sscCrosstab-class}
\docType{class}
\alias{sscCrosstab-class}
\alias{image,sscCrosstab-method}
\title{Pairwise crosstabulations}
\description{An \code{sscCrosstab} object is a pairwise crosstabulation
  of two or more factors expressed as an \code{sscMatrix} plus
  additional information.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("sscCrosstab", ...)}
or by a call to the constructor function \code{sscCrosstab}.
}
\section{Slots}{
  \describe{
    \item{\code{Gp}:}{integer vector of pointers to the beginning of
      each group of columns.  Its length is 1 greater than the number of
      groups.  Successive differences give the number of levels of each
      factor.} 
    \item{\code{perm}:}{Integer permutation vector giving a
      fill-reducing permutation for the Cholesky decomposition.  The
      permutation is constrained to keep the groups of columns
      corresponding to different factors distinct.}
    \item{\code{uplo}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{p}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{i}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{x}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{Dim}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{factorization}:}{as for \code{"sscMatrix"} objects.}
  }
}
\section{Extends}{
Class \code{"sscMatrix"}, directly.
Class \code{"cscMatrix"}, by class \code{"sscMatrix"}.
}
\section{Methods}{
  \describe{
    \item{image}{\code{signature(x = "sscCrosstab")}: plots an image of
      \code{x} using the \code{\link[lattice]{levelplot}} function}
  }
}
%\references{}
%\author{}
%\note{}
\seealso{
 \code{\link{sscMatrix-class}}, \code{\link{sscCrosstab}}
}
%\examples{}
\keyword{classes}

\eof
\name{sscCrosstab}
\alias{sscCrosstab}
\title{Create pairwise crosstabulation}
\description{
  Create the pairwise crosstabulation of two or more factors and store
  it as an object of class \code{"sscCrosstab"} which consists of a
  symmetric, sparse, positive semidefinite matrix, a vector of the
  counts of the levels in each factor, and, optionally, a permutation
  and inverse permutation that will minimize fill-in in the Cholesky
  decomposition of this matrix while maintaining separation of the
  groups of columns corresponding to different factors.
}
\usage{
sscCrosstab(flist, upper = TRUE)
}
\arguments{
  \item{flist}{A list of two or more factors.  All factors must have the
    same length.}
  \item{upper}{logical - if \code{TRUE} the upper triangle of the
    pairwise cross-tabulation matrix is computed and returned.  Otherwise
    the lower triangle is returned.  Defaults to \code{TRUE}.}
}
%\details{}
\value{
  An object of class \code{"sscCrosstab"}.
}
%\references{}
%\author{}
%\note{}
\seealso{\code{\link{sscCrosstab-class}}}
%\examples{}
\keyword{manip}
\keyword{algebra}

\eof
\name{sscMatrix-class}
\docType{class}
\alias{sscMatrix-class}
\alias{solve,sscMatrix,matrix-method}
\alias{chol,sscMatrix,missing-method}
\alias{chol,sscMatrix,logical-method}
\alias{t,sscMatrix-method}
\alias{coerce,sscMatrix,tripletMatrix-method}
\alias{coerce,sscMatrix,geMatrix-method}
\title{Symmetric, compressed, sparse column matrices}
\description{The \code{sscMatrix} class is a class of symmetric, sparse
  matrices in the compressed, column-oriented format.  In this
  implementation the non-zero elements in the columns are sorted into
  increasing row order.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("sscMatrix", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{uplo}:}{A character object indicating if the upper
      triangle (\code{"U"} or \code{"u"}) or the lower triangle
      (\code{"L"} or \code{"l"}) is stored.  At present only the lower
      triangle form is allowed.}
    \item{\code{p}:}{Object of class \code{"integer"} of pointers, one
      for each column, to the initial (zero-based) index of elements in
      the column.}
    \item{\code{i}:}{Object of class \code{"integer"} of length nnzero
      (number of non-zero elements).  These are the row numbers for
      each non-zero element in the matrix.}
    \item{\code{x}:}{Object of class \code{"numeric"} - the non-zero
      elements of the matrix.}
    \item{\code{factorization}:}{Object of class \code{"list"} - a list
      of factorizations of the matrix. }
    \item{\code{Dim}:}{Object of class \code{"integer"} - the dimensions
     of the matrix - must be an integer vector with exactly two
     non-negative values.}
  }
}
\section{Extends}{
Class \code{"cscMatrix"}, directly.
}
\section{Methods}{
  \describe{
    \item{solve}{\code{signature(a = "sscMatrix", b = "matrix")}: Solve
      a linear system of equations defined by \code{x} using a Cholesky
      decomposition.}
    \item{chol}{\code{signature(x = "sscMatrix", pivot = "logical")}:
      Returns (and stores) the Cholesky decomposition of the matrix
      \code{x}. If \code{pivot} is \code{TRUE} (the default) Metis is
      used to create a reordering of the rows and columns of \code{x} so
      as to minimize fill-in.}
    \item{coerce}{\code{signature(from = "sscMatrix", to = "tripletMatrix")}}
    \item{coerce}{\code{signature(from = "sscMatrix", to = "geMatrix")}}
  }
}
%\references{}
%\author{}
%\note{}
\seealso{
  \code{\link{cscMatrix-class}}, \code{\link{tripletMatrix-class}},
  \code{\link{geMatrix-class}}
}
%\examples{}
\keyword{classes}
\keyword{algebra}

\eof
\name{ssclme-class}
\docType{class}
\alias{ssclme-class}
\alias{coef,ssclme-method}
\alias{coef<-,ssclme-method}
\alias{coerce,ssclme,sscMatrix-method}
\alias{coerce,ssclme,tscMatrix-method}
\title{lme models as sparse, symmetric matrices}
\description{A representation of a linear mixed-effects model using a
  combination of sparse, symmetric, column-oriented matrices and dense matrices.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("ssclme", ...)}
or, more commonly, via the \code{ssclme} constructor function.}
}
\section{Slots}{
  \describe{
    \item{\code{Gp}:}{integer vector of pointers to the beginning of
      each group of columns.  Its length is 1 greater than the number of
      groups.  Successive differences give the number of levels of each
      factor.} 
    \item{\code{p}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{i}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{x}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{Dim}:}{as for \code{"sscMatrix"} objects.}
    \item{\code{nc}:}{An integer vector of the number of columns in each
      model matrix.  The last entry is \code{p+1} where \code{p} is the
      number of columns in the fixed-effects model matrix.}
    \item{\code{ZtX}:}{A (dense) matrix equivalent to \code{crossprod(Z,X)}.}
    \item{\code{XtX}:}{A (dense) matrix equivalent to the upper triangle
      of \code{crossprod(X)} where \code{X} has the response column appended.}
    \item{\code{Lp}:}{An integer vector of pointers to the beginnings of
      the columns of the unit lower triangular factor L in the
      LDL' decomposition of Z'Z+W.}
    \item{\code{Parent}:}{An integer vector from the symbolic analysis
      of the cross-tabulation.  It is used to compute L efficiently.}
    \item{\code{Li}:}{Row indices of L.}
    \item{\code{D}:}{Diagonal of the diagonal matrix in the
      LDL' decomposition of Z'Z+W.}
    \item{\code{DIsqrt}:}{Square root of the inverse of the diagonal of
      D in LDL'.}
    \item{\code{Lx}:}{Non-zero elements in the (strict) lower triangle
      of L.}
    \item{\code{RZX}:}{A dense matrix corresponding to \code{ZtX} in the
      decomposition.}
    \item{\code{RXX}:}{A dense matrix corresponding to \code{XtX} in the
      decomposition.}
    \item{\code{LIp}:}{An integer vector of pointers to
      the columns of the unit lower triangular inverse of L.}
    \item{\code{LIi}:}{Row indices of L-inverse.}
    \item{\code{LIx}:}{Non-zero elements in the (strict) lower triangle
      of L-inverse.}
    \item{\code{status}:}{Logical vector of length 2 indicating if the
      object has been factored and if the factorization has been
      inverted.}
    \item{\code{deviance}:}{Numeric vector of length 2 containing the
      deviance corresponding to the maximum likelihood (ML) and REML
      criteria.  This slot's contents are current if
      \code{status$factored} is \code{TRUE}.}
    \item{\code{devComp}:}{Numeric vector of length 4 giving the
      components used to calculate the deviance. This slot's contents
      are current if \code{status$factored} is \code{TRUE}.}
    \item{\code{bVar}:}{A list of numeric 3-dimensional arrays giving
      the conditional variances of the random effects. This slot's
      contents are current if \code{status$inverted} is \code{TRUE}.}
    \item{\code{Omega}:}{A list of numeric matrices providing the
      components of symmetric, positive-definite matrix Omega.  Only the
      upper triangle of each component is used and stored.}
  }
}
\section{Methods}{
  \describe{
    \item{coef}{\code{signature(object = "ssclme")}: Extract the
      "coefficients" from the object as a numeric vector.  If the
      optional argument \code{unconst} is \code{FALSE} (the default),
      the values in the upper triangles of the \code{Omega} matrices are
      concatenated.  Within each matrix the diagonal is given first then
      the elements above the diagonal are given row-wise.  If
      \code{unconst} is \code{TRUE}, an unconstrained parameterization
      based on the LDL decomposition (logarithms of diagonal elements of
      D followed by elements of the strict lower triangle of L
      column-wise) are given.}
    \item{coef<-}{\code{signature(object = "ssclme", value =
	"numeric")}: Assign the \code{Omega} matrices from a numeric
      vector.  The assignment depends on the optional argument
      \code{unconst} as described above.}
    \item{coerce}{\code{signature(from = "ssclme", to = "sscMatrix")}:
      return the current Z'Z matrix as an \code{sscMatrix} object.}
    \item{coerce}{\code{signature(from = "ssclme", to = "tscMatrix")}:
      return the current L matrix from the LDL decomposition of Z'Z as
      a \code{tscMatrix} object.}
  }
}
%\references{}
%\author{}
%\note{}
\seealso{
  \code{\link{sscCrosstab-class}}, \code{\link{sscMatrix-class}},
  \code{\link{tscMatrix-class}}
}
%\examples{}
\keyword{classes}

\eof
\name{syMatrix-class}
\docType{class}
\alias{%*%,geMatrix,syMatrix-method}
\alias{%*%,syMatrix,geMatrix-method}
\alias{syMatrix-class}
\alias{coerce,syMatrix,geMatrix-method}
\alias{coerce,syMatrix,matrix-method}
\alias{norm,syMatrix,character-method}
\alias{norm,syMatrix,missing-method}
\alias{t,syMatrix-method}
\title{Class "syMatrix" of symmetric matrices}
\description{The \code{"syMatrix"} class is the class of symmetric
  matrices in non-packed storage.  Only the upper triangle or the lower
  triangle is stored.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("syMatrix", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{uplo}:}{Object of class \code{"character"}. Must be
      either "U", for upper triangular, and "L", for lower triangular.}
    \item{\code{x}:}{Object of class \code{"numeric"}. The numeric
      values that constitute the matrix, stored in column-major order.}
    \item{\code{Dim}:}{Object of class \code{"integer"}. The dimensions
      of the matrix which must be a two-element vector of non-negative
      integers.}
    \item{\code{norm}:}{Object of class \code{"numeric"}. A named
      numeric vector of norms of the matrix.  Some possible components
      are \code{"O"}, the one norm; \code{"I"}, the infinity norm;
      \code{"F"}, the Frobenius norm; and \code{"M"}, the maximum
      absolute value.}
    \item{\code{rcond}:}{Object of class \code{"numeric"}. A named
      numeric vector of reciprocal condition numbers in either the
      1-norm \code{"O"} or the infinity norm \code{"I"}.}
    \item{\code{factorization}:}{Object of class \code{"list"}.  A named
      list of factorizations that have been computed for the matrix.}
  }
}
\section{Extends}{
Class \code{"geMatrix"}, directly.
Class \code{"Matrix"}, by class \code{"geMatrix"}.
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "syMatrix", to = "geMatrix")}}
    \item{coerce}{\code{signature(from = "syMatrix", to = "matrix")}}
    \item{norm}{\code{signature(x = "syMatrix", type = "character")}}
  }
}
%\references{}
%\author{}
\seealso{
  \code{\link{geMatrix-class}}, \code{\link{Matrix-class}}
}
%\examples{}
\keyword{classes}

\eof
\name{trMatrix-class}
\docType{class}
\alias{%*%,geMatrix,trMatrix-method}
\alias{%*%,trMatrix,geMatrix-method}
\alias{coerce,trMatrix,geMatrix-method}
\alias{coerce,trMatrix,matrix-method}
\alias{crossprod,trMatrix,missing-method}
\alias{determinant,trMatrix,logical-method}
\alias{determinant,trMatrix,missing-method}
\alias{norm,trMatrix,character-method}
\alias{norm,trMatrix,missing-method}
\alias{rcond,trMatrix,character-method}
\alias{rcond,trMatrix,missing-method}
\alias{solve,trMatrix,matrix-method}
\alias{solve,trMatrix,missing-method}
\alias{t,trMatrix-method}
\alias{trMatrix-class}
\title{Triangular, dense, non-packed, real matrices}
\description{The \code{"trMatrix"} class is the class of triangular
  matrices in dense, non-packed storage.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("trMatrix", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{uplo}:}{Object of class \code{"character"}. Must be
      either "U", for upper triangular, and "L", for lower triangular.}
    \item{\code{diag}:}{Object of class \code{"character"}. Must be
      either \code{"U"}, for unit triangular (diagonal is all ones), or
      \code{"N"} for non-unit.  The implicit diagonal elements are not
      explicitly stored when \code{diag} is \code{"U"}.}
    \item{\code{x}:}{Object of class \code{"numeric"}. The numeric
      values that constitute the matrix, stored in column-major order.}
    \item{\code{Dim}:}{Object of class \code{"integer"}. The dimensions
      of the matrix which must be a two-element vector of non-negative
      integers.}
    \item{\code{norm}:}{Object of class \code{"numeric"}. A named
      numeric vector of norms of the matrix.  Some possible components
      are \code{"O"}, the one norm; \code{"I"}, the infinity norm;
      \code{"F"}, the Frobenius norm; and \code{"M"}, the maximum
      absolute value.}
    \item{\code{rcond}:}{Object of class \code{"numeric"}. A named
      numeric vector of reciprocal condition numbers in either the
      1-norm \code{"O"} or the infinity norm \code{"I"}.}
    \item{\code{factorization}:}{Object of class \code{"list"}.  A named
      list of factorizations that have been computed for the matrix.}
  }
}
\section{Extends}{
Class \code{"geMatrix"}, directly.
Class \code{"Matrix"}, by class \code{"geMatrix"}.
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "trMatrix", to = "geMatrix")}}
    \item{coerce}{\code{signature(from = "trMatrix", to = "matrix")}}
    \item{norm}{\code{signature(x = "trMatrix", type = "character")}}
    \item{rcond}{\code{signature(x = "trMatrix", type = "character")}}    
    \item{solve}{\code{signature(a = "trMatrix", b = "missing")}}
    \item{solve}{\code{signature(a = "trMatrix", b = "matrix")}}
  }
}
%\references{}
%\author{}
\seealso{
  \code{\link{geMatrix-class}}, \code{\link{Matrix-class}}
}
%\examples{}
\keyword{classes}

\eof
\name{tripletMatrix-class}
\docType{class}
\alias{tripletMatrix-class}
\alias{coerce,tripletMatrix,geMatrix-method}
\alias{coerce,tripletMatrix,cscMatrix-method}
\alias{image,tripletMatrix-method}
\alias{t,tripletMatrix-method}
\title{Class "tripletMatrix" sparse matrices in triplet form}
\description{The \code{"tripletMatrix"} class is the class of sparse
  matrices stored as (possibly redundant) triplets.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("tripletMatrix", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{i}:}{Object of class \code{"integer"} - the row indices
      of non-zero entries.}
    \item{\code{j}:}{Object of class \code{"integer"} - the column
      indices of non-zero entries.  Must be the same length as slot \code{i}.}
    \item{\code{x}:}{Object of class \code{"numeric"} - the (non-zero)
      entry at position \code{(i,j)}.  Must be the same length as slot
      \code{i}. If an index pair occurs more than once the corresponding
      values of slot \code{x} are added to form the element of the matrix.}
    \item{\code{Dim}:}{Object of class \code{"integer"} of length 2 -
      the dimensions of the matrix.}
  }
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "tripletMatrix", to = "cscMatrix")}}
    \item{coerce}{\code{signature(from = "tripletMatrix", to = "geMatrix")}}
    \item{image}{\code{signature(x = "tripletMatrix")}: plots an image of
      \code{x} using the \code{\link[lattice]{levelplot}} function}
    \item{t}{\code{signature(x = "tripletMatrix")}: returns the transpose of
      \code{x}}
  }
}
%\references{}
%\author{}
\note{Triplet matrices are a convenient form in which to construct sparse
  matrices after which they can be coerced to \code{cscMatrix} objects.}
\seealso{
  \code{\link{cscMatrix-class}}
}
%\examples{}
\keyword{classes}
\keyword{algebra}

\eof
\name{tscMatrix-class}
\docType{class}
\alias{tscMatrix-class}
\alias{t,tscMatrix-method}
\alias{coerce,tscMatrix,tripletMatrix-method}
\alias{coerce,tscMatrix,geMatrix-method}
\title{Triangular, compressed, sparse column matrices}
\description{The \code{sscMatrix} class is a class of triangular, sparse
  matrices in the compressed, column-oriented format.  In this
  implementation the non-zero elements in the columns are sorted into
  increasing row order.}
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("tscMatrix", ...)}.
}
\section{Slots}{
  \describe{
    \item{\code{uplo}:}{A character object indicating if the matrix is upper
      triangular (\code{"U"} or \code{"u"}) or lower triangular
      (\code{"L"} or \code{"l"}).}
    \item{\code{p}:}{Object of class \code{"integer"} of pointers, one
      for each column, to the initial (zero-based) index of elements in
      the column.}
    \item{\code{i}:}{Object of class \code{"integer"} of length nnzero
      (number of non-zero elements).  These are the row numbers for
      each non-zero element in the matrix.}
    \item{\code{x}:}{Object of class \code{"numeric"} - the non-zero
      elements of the matrix.}
    \item{\code{factorization}:}{Object of class \code{"list"} - a list
      of factorizations of the matrix. }
    \item{\code{Dim}:}{Object of class \code{"integer"} - the dimensions
     of the matrix - must be an integer vector with exactly two
     non-negative values.}
  }
}
\section{Extends}{
  Class \code{"cscMatrix"}, directly.
}
\section{Methods}{
  \describe{
    \item{coerce}{\code{signature(from = "tscMatrix", to = "tripletMatrix")}}
    \item{coerce}{\code{signature(from = "tscMatrix", to = "geMatrix")}}
    \item{t}{\code{signature(x = "tscMatrix")}: returns the transpose of
      \code{x}}
  }
}
%\references{}
%\author{}
%\note{}
\seealso{
  \code{\link{cscMatrix-class}}, \code{\link{tripletMatrix-class}},
  \code{\link{geMatrix-class}}
}
%\examples{}
\keyword{classes}
\keyword{algebra}

\eof
\name{unpack}
\title{Full Storage Representation of Packed Matrices}
\usage{
unpack(x, \dots)
}
\alias{unpack}
\description{
    Expands decompositions stored in compact form into matrix factors.
}
\arguments{
    \item{x}{
	a matrix stored in packed form. 
    }
  \item{\dots}{further arguments passed to or from other methods.}
}
\value{
    A \code{Matrix} object containing the full-storage representation of \code{x}.
}
\details{
    This is a generic function with special methods for different types
    of packed matrices.
    Use \code{\link{methods}("unpack")} to list all the methods for the
    \code{unpack} generic.
}
\examples{
\dontrun{
x <- Diagonal( 1:3)
x
unpack(x)
}
}
\keyword{array}
\keyword{algebra}

\eof
\name{y}
\alias{y}
\docType{data}
\title{A sample response vector}
\description{
The response vector of length 1850 corresponding to the model matrix \code{mm}.
}
\usage{data(y)}
\format{
  The format is:
 num [1:1850] 64.07  5.88 64.03  5.96 76.41 ...
}
%\details{}
%\source{}
\seealso{\code{\link{mm}}}
\references{
  Roger Koenker and Pin Ng (2003), ``SparseM: A sparse matrix package
  for R'', \emph{J. of Statistical Software}, 8(6).
}
\examples{
data(y)
}
\keyword{datasets}

\eof
